@@ -469,6 +469,8 @@ is_tds_type_valid(int type)
 #define TLS_STR_OPENSSL_CIPHERS "openssl ciphers"
 /* enable old TLS v1, required for instance if you are using a really old Windows XP */
 #define TDS_STR_ENABLE_TLS_V1 "enable tls v1"
+/* enable old TLS v1.1 */
+#define TDS_STR_ENABLE_TLS_V1_1 "enable tls v1.1"
 
 
 /* TODO do a better check for alignment than this */
@@ -550,6 +552,8 @@ typedef struct tds_login
 	unsigned int readonly_intent:1;
 	unsigned int enable_tls_v1:1;
 	unsigned int enable_tls_v1_specified:1;
+	unsigned int enable_tls_v1_1:1;
+	unsigned int enable_tls_v1_1_specified:1;
 	unsigned int server_is_valid:1;
 } TDSLOGIN;
 
@@ -1077,6 +1081,7 @@ typedef struct tds_poll_wakeup
 struct tds_connection
 {
 	TDS_USMALLINT tds_version;
+	bool corked;
 	TDS_UINT product_version;	/**< version of product (Sybase/MS and full version) */
 	char *product_name;
 
@@ -1322,7 +1327,7 @@ void tds_srv_charset_changed(TDSCONNECTION * conn, const char *charset);
 void tds7_srv_charset_changed(TDSCONNECTION * conn, TDS_UCHAR collate[5]);
 int tds_iconv_alloc(TDSCONNECTION * conn);
 void tds_iconv_free(TDSCONNECTION * conn);
-TDSICONV *tds_iconv_from_collate(TDSCONNECTION * conn, TDS_UCHAR collate[5]);
+TDSICONV *tds_iconv_from_collate(TDSCONNECTION * conn, const TDS_UCHAR collate[5]);
 
 
 /* mem.c */
@@ -1550,13 +1555,14 @@ char *tds_prwsaerror(int erc);
 void tds_prwsaerror_free(char *s);
 ptrdiff_t tds_connection_read(TDSSOCKET * tds, unsigned char *buf, size_t buflen);
 ptrdiff_t tds_connection_write(TDSSOCKET *tds, const unsigned char *buf, size_t buflen, int final);
+void tds_connection_coalesce(TDSSOCKET *tds);
+void tds_connection_flush(TDSSOCKET *tds);
 #define TDSSELREAD  POLLIN
 #define TDSSELWRITE POLLOUT
 int tds_select(TDSSOCKET * tds, unsigned tds_sel, int timeout_seconds);
 void tds_connection_close(TDSCONNECTION *conn);
 ptrdiff_t tds_goodread(TDSSOCKET * tds, unsigned char *buf, size_t buflen);
 ptrdiff_t tds_goodwrite(TDSSOCKET * tds, const unsigned char *buffer, size_t buflen);
-void tds_socket_flush(TDS_SYS_SOCKET sock);
 int tds_socket_set_nonblocking(TDS_SYS_SOCKET sock);
 int tds_wakeup_init(TDSPOLLWAKEUP *wakeup);
 void tds_wakeup_close(TDSPOLLWAKEUP *wakeup);
